@@ -143,12 +143,12 @@ QImage Utility::borderImage(const QPixmap &px, const QMargins &borders,
     return image;
 }
 
-xcb_atom_t Utility::internAtom(const char *name)
+xcb_atom_t Utility::internAtom(const char *name, bool only_if_exists)
 {
     if (!name || *name == 0)
         return XCB_NONE;
 
-    xcb_intern_atom_cookie_t cookie = xcb_intern_atom(QX11Info::connection(), true, strlen(name), name);
+    xcb_intern_atom_cookie_t cookie = xcb_intern_atom(QX11Info::connection(), only_if_exists, strlen(name), name);
     xcb_intern_atom_reply_t *reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, 0);
 
     if (!reply)
